<?php
/*
Plugin Name: More Feed Excerpt
Plugin URI: http://www.g-loaded.eu/2008/05/08/more-feed-excerpt-wordpress-plugin/
Description: Uses the &lt;!--more--&gt; tag, if it exists inside the post, to create the feed entry's excerpt. The &lt;!--more--&gt; tag is used only if full-text feeds are enabled. This was the default WordPress pre-v2.5 functionality.
Version: 0.1.1
Author: George Notaras
Author URI: http://www.g-loaded.eu/
*/

/**
 *  Copyright 2008 George Notaras <gnot@g-loaded.eu>, CodeTRAX.org 
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License. 
 */


/**
 * Uses the <!--more--> tag, if it exists, to create the feed entry's excerpt.
 *
 * Since WordPress 2.5, the <!--more--> tag is not used any more to split the
 * feed content. This hack reverts the functionality back to what people have
 * been used to in older versions.
 *
 * If the following two conditions are met:
 *
 *     - The user has enabled full-text feeds in the WordPress settings.
 *     - The <!--more--> tag exists within the post's content.
 *
 * Then, the post is split at the <!--more--> tag and the first excerpt
 * is returned as the entry's content.
 *
 * Moreover, any inconsistencies with open HTML tags are addressed with the
 * built-in 'balanceTags' function.
 */

function mfe_More_Feed_Excerpt($PostBody) {

	if ( is_feed() and !get_option('rss_use_excerpt') ) {

		$FeedSplitPattern = "/(<br \/>\s)?<span id=\"more-\d+\"><\/span>/";
		$excerpts = preg_split($FeedSplitPattern, $PostBody, 2, PREG_SPLIT_NO_EMPTY);
		if ( count($excerpts) > 1 ) {
			$PostBody = balanceTags( $excerpts[0], $force = true );
		}

	}
	return rtrim($PostBody);
}

add_filter('the_content_feed', 'mfe_More_Feed_Excerpt');

?>